name = "bioscan-dataset"
path = name.lower().replace("-", "_").replace(" ", "_")
version = "1.0.0"
author = "Scott C. Lowe"
author_email = "scott.code.lowe@gmail.com"
description = "PyTorch torchvision-style datasets for BIOSCAN-1M and BIOSCAN-5M."
url = "https://github.com/bioscan-ml/dataset"
license = "MIT"
